"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Api = void 0;
const common_1 = require("@nestjs/common");
const swagger_1 = require("@nestjs/swagger");
const constants_1 = require("../constants");
const core_interface_1 = require("../interfaces/core.interface");
const mtenant_error_1 = require("../errors/mtenant.error");
function Api(options = {}) {
    switch (options.transport || constants_1.DEFAULT_TRANSPORT) {
        case core_interface_1.TenantTransport.HTTP:
            const decorators = [
                (0, swagger_1.ApiHeader)({
                    name: options.headerName || constants_1.MT_HEADER_NAME,
                    description: 'Header used to set custom tenant or the call.',
                    required: false,
                    allowEmptyValue: true,
                }),
            ];
            if (options.includeQuery) {
                decorators.push((0, swagger_1.ApiQuery)({
                    name: options.queryParameterName || constants_1.MT_QUERY_PARAMETER_NAME,
                    description: 'Query parameter used to set custom tenant or the call.',
                    required: false,
                    allowEmptyValue: true,
                }));
            }
            return (0, common_1.applyDecorators)(...decorators);
        default:
            throw new mtenant_error_1.BaseError(`Unknown tenant transport "${this.options.transport}"`);
    }
}
exports.Api = Api;
