"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Entity = exports.getTenancyService = exports.injectTenancyService = exports.isTenantEntity = void 0;
const sequelize_typescript_1 = require("sequelize-typescript");
const constants_1 = require("./constants");
const tenant_entity_1 = require("./tenant.entity");
function isTenantEntity(target) {
    return (typeof target === typeof sequelize_typescript_1.Model &&
        Reflect.hasMetadata(constants_1.TENANT_ENTITY_METADATA_FIELD, target) &&
        Reflect.getMetadata(constants_1.TENANT_ENTITY_METADATA_FIELD, target) === true);
}
exports.isTenantEntity = isTenantEntity;
function injectTenancyService(target, service) {
    Reflect.defineMetadata(constants_1.TENANCY_SERVICE_METADATA_FIELD, service, target);
}
exports.injectTenancyService = injectTenancyService;
function getTenancyService(target) {
    return Reflect.hasMetadata(constants_1.TENANCY_SERVICE_METADATA_FIELD, target)
        ? Reflect.getMetadata(constants_1.TENANCY_SERVICE_METADATA_FIELD, target)
        : null;
}
exports.getTenancyService = getTenancyService;
function Entity(options) {
    return (target) => {
        const tenancyOptions = Object.assign({}, constants_1.DEFAULT_ENTITY_OPTIONS, options || {});
        Object.defineProperty(target, 'switchTenancy', {
            value: (state) => {
                Reflect.defineMetadata(constants_1.TENANT_ENTITY_METADATA_FIELD, state, target);
            },
            writable: false,
        });
        target.prototype.getTenant = function () {
            return this[tenancyOptions.tenantField];
        };
        target.prototype.getTenantId = function () {
            const tenant = this.getTenant();
            const id = this[tenancyOptions.idField];
            return `${tenant}/${id}`;
        };
        (0, tenant_entity_1.enhanceTenantEntity)(target, tenancyOptions);
        target.switchTenancy(true);
    };
}
exports.Entity = Entity;
