"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SequelizeStorage = void 0;
const tslib_1 = require("tslib");
class SequelizeStorage {
    constructor(storageRepository) {
        this.storageRepository = storageRepository;
    }
    add(tenant, settings) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            return this.storageRepository.create({
                tenant,
                settings: this.encode(settings),
            });
        });
    }
    remove(tenant) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            return this.storageRepository.destroy({ where: { tenant } });
        });
    }
    exists(tenant) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            return (yield this.storageRepository.count({ where: { tenant } })) > 0;
        });
    }
    updateSettings(tenant, settings) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            yield (this.storageRepository.update({ settings: this.encode(settings) }, { where: { tenant } }));
            return { tenant, settings };
        });
    }
    get(tenant) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            if (!tenant) {
                const entries = yield (this.storageRepository.findAll({ attributes: ['tenant', 'settings'] }));
                return entries.map((entry) => {
                    const { tenant, settings } = entry;
                    return { tenant, settings: this.decode(settings) };
                });
            }
            const { settings } = yield this.storageRepository.findOne({
                where: { tenant },
                attributes: ['settings'],
            });
            return { tenant, settings: this.decode(settings) };
        });
    }
    encode(settings) {
        return settings ? JSON.stringify(settings) : null;
    }
    decode(rawSettings) {
        return rawSettings ? JSON.parse(rawSettings.toString()) : null;
    }
}
exports.SequelizeStorage = SequelizeStorage;
